<?php

add_action( 'init', function() {

	class acf_field_relationship_nogroup extends acf_field_relationship {

		function initialize() {
			
			// vars
			$this->name = 'relationship_nogroup';
			$this->label = __("Relationship (No Grouping)",'acf');
			$this->category = 'relational';
			$this->defaults = array(
				'post_type'			=> array(),
				'taxonomy'			=> array(),
				'min' 				=> 0,
				'max' 				=> 0,
				'filters'			=> array('search', 'post_type', 'taxonomy'),
				'elements' 			=> array(),
				'return_format'		=> 'object'
			);
			
			// extra
			add_action('wp_ajax_acf/fields/relationship_nogroup/query',			array($this, 'ajax_query'));
			add_action('wp_ajax_nopriv_acf/fields/relationship_nogroup/query',	array($this, 'ajax_query'));
			
		}

		function ajax_query() {
		
			// validate
			if( !acf_verify_ajax() ) die();
			
			
			// get choices
			$response = $this->get_ajax_query( $_POST );
			
			
			// return
			acf_send_ajax_results($response);
				
		}

		function get_ajax_query( $options = array() ) {

			// defaults
			$options = wp_parse_args($options, array(
				'post_id'		=> 0,
				's'				=> '',
				'field_key'		=> '',
				'paged'			=> 1,
				'post_type'		=> '',
				'taxonomy'		=> ''
			));
			
			
			// load field
			$field = acf_get_field( $options['field_key'] );
			if( !$field ) return false;
			
			
			// vars
			$results = array();
			$post_titles = array();
			$args = array();
			$s = false;
			$is_search = false;
			
			
			// paged
			$args['posts_per_page'] = 20;
			$args['paged'] = intval($options['paged']);

			
			// search
			if( $options['s'] !== '' ) {
				
				// strip slashes (search may be integer)
				$s = wp_unslash( strval($options['s']) );
				
				
				// update vars
				$args['s'] = $s;
				$is_search = true;
				
			}
			
			
			// post_type
			if( !empty($options['post_type']) ) {
				
				$args['post_type'] = acf_get_array( $options['post_type'] );
			
			} elseif( !empty($field['post_type']) ) {
			
				$args['post_type'] = acf_get_array( $field['post_type'] );
				
			} else {
				
				$args['post_type'] = acf_get_post_types();
				
			}
			
			
			// taxonomy
			if( !empty($options['taxonomy']) ) {
				
				// vars
				$term = acf_decode_taxonomy_term($options['taxonomy']);
				
				
				// tax query
				$args['tax_query'] = array();
				
				
				// append
				$args['tax_query'][] = array(
					'taxonomy'	=> $term['taxonomy'],
					'field'		=> 'slug',
					'terms'		=> $term['term'],
				);
				
				
			} elseif( !empty($field['taxonomy']) ) {
				
				// vars
				$terms = acf_decode_taxonomy_terms( $field['taxonomy'] );
				
				
				// append to $args
				$args['tax_query'] = array(
					'relation' => 'OR',
				);
				
				
				// now create the tax queries
				foreach( $terms as $k => $v ) {
				
					$args['tax_query'][] = array(
						'taxonomy'	=> $k,
						'field'		=> 'slug',
						'terms'		=> $v,
					);
					
				}
				
			}	
			
			
			// filters
			$args = apply_filters('acf/fields/relationship/query', $args, $field, $options['post_id']);
			$args = apply_filters('acf/fields/relationship/query/name=' . $field['name'], $args, $field, $options['post_id'] );
			$args = apply_filters('acf/fields/relationship/query/key=' . $field['key'], $args, $field, $options['post_id'] );

			// get posts
			$posts = acf_get_posts( $args );
			
			// bail early if no posts
			if( empty($posts) ) return false;

			// convert post objects to post titles
			foreach( $posts as $post ) {
				
				$post_titles[ $post->ID ] = $this->get_post_title( $post, $field, $options['post_id'] );
				
			}

			// order posts by search
			if( $is_search && empty($args['orderby']) && isset($args['s']) ) {
				
				$post_titles = acf_order_by_search( $post_titles, $args['s'] );
				
			}

			// append to $results
			foreach( array_keys($post_titles) as $post_id ) {
				
				$results[] = $this->get_post_result( $post_id, $post_titles[ $post_id ]);
				
			}

			// vars
			$response = array(
				'results'	=> $results,
				'limit'		=> $args['posts_per_page']
			);
			
			
			// return
			return $response;
				
		}

	}

	// initialize
	acf_register_field_type( 'acf_field_relationship_nogroup' );

} );

add_action('acf/input/admin_enqueue_scripts', function() {

	wp_enqueue_script( 'acf-field-relationship-nogroup-js', plugin_dir_url( __FILE__ ) . 'acf-field-relationship-nogroup.js', false, '1.0.0' );
	
});
